import { BasicColumn, FormSchema } from '@/components/Table';
import { h } from 'vue';
import {Switch, Tag} from 'ant-design-vue';
import Icon from '@/components/Icon/Icon.vue';
import {useMessage} from "@/hooks/web/useMessage";
import {statusChange} from "@/api/system/dept/dept";

export const columns: BasicColumn[] = [
  {
    title: '部门名称',
    dataIndex: 'deptName',
    width: 200,
    align: 'left',
  },
  {
    title: '排序',
    dataIndex: 'orderNum',
    width: 50,
  },
  {
    title: '状态',
    dataIndex: 'flag',
    width: 120,
    customRender: ({ record }) => {
      if (!Reflect.has(record, 'pendingStatus')) {
        record.pendingStatus = false;
      }
      return h(Switch, {
        checked: record.flag === '1',
        loading: record.pendingStatus,
        onChange(checked: CheckedType) {
          record.pendingStatus = true;
          const newStatus = checked ? '1' : '0';
          const { createMessage } = useMessage();
          const params = {
            businessId: record.businessId,
            flag: newStatus,
            parentId: record.parentId,
            deptName: record.deptName,
            orderNum: record.orderNum,
            leader: record.leader,
            phone: record.phone,
            email: record.email,
          }
          statusChange(params)
            .then(() => {
              record.flag = newStatus;
              const text = record.flag === '1' ? '启用' : '停用'
              createMessage.success( text + `成功`);
            })
            .catch(() => {
              // createMessage.error('操作失败');
            })
            .finally(() => {
              record.pendingStatus = false;
            });
        },
      });
    },
  },
  {
    title: '负责人',
    dataIndex: 'leader',
    width: 50,
  },
  {
    title: '联系电话',
    dataIndex: 'phone',
    width: 50,
  },
  {
    title: '创建时间',
    dataIndex: 'createDate',
    width: 180,
  },
];

const isDir = (menuType: string) => menuType === 'M';
const isMenu = (menuType: string) => menuType === 'C';
const isButton = (menuType: string) => menuType === 'F';

export const searchFormSchema: FormSchema[] = [
  {
    field: 'deptName',
    label: '部门名称',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'flag',
    label: '部门状态',
    component: 'Select',
    componentProps: {
      options: [
        { label: '启用', value: '1' },
        { label: '停用', value: '0' },
      ],
    },
    colProps: { span: 8 },
  },
];

export const formSchema: FormSchema[] = [
  {
    field: 'parentId',
    label: '上级部门',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'deptName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
    ifShow: ({ values }) => values.parentId !== 0,
  },
  {
    field: 'deptName',
    label: '部门名称',
    component: 'Input',
    required: true,
  },
  {
    field: 'orderNum',
    label: '部门排序',
    component: 'InputNumber',
    required: true,
  },
  {
    field: 'leader',
    label: '负责人',
    component: 'Input',
  },
  {
    field: 'phone',
    label: '联系电话',
    component: 'Input',
  },
  {
    field: 'email',
    label: '邮箱',
    component: 'Input',
  },
  {
    field: 'flag',
    label: '部门状态',
    component: 'RadioGroup',
    componentProps: {
      options: [
        { label: '启用', value: '1' },
        { label: '停用', value: '0' },
      ],
    },
  },
];
