import { BasicColumn, FormSchema } from '@/components/Table';
import { h, defineComponent } from 'vue';
import { Switch } from 'ant-design-vue';
import { useMessage } from '@/hooks/web/useMessage';
import { schemas } from '@/views/demo/page/form/basic/data';
import {
  changeFlagApi,
  changeDataFlagApi,
  getDictListByPage,
  DictDetailApi, getDictDataByType
} from '@/api/system/dict/dict';
import { log } from 'vxe-pc-ui';
import { useRouter } from 'vue-router';
const route = useRouter()
type CheckedType = boolean | string | number;
export const columns: BasicColumn[] = [
  {
    title: '字典编码',
    dataIndex: 'businessId',
    width: 100,
  },
  {
    title: '字典标签',
    dataIndex: 'dictLabel',
    width: 100,
  },
  {
    title: '字典键值',
    dataIndex: 'dictValue',
    width: 100,
  },
  {
    title: '字典排序',
    dataIndex: 'dictSort',
    width: 200,
  },
  {
    title: '状态',
    dataIndex: 'flag',
    width: 60,
    customRender: ({ record }) => {
      if (!Reflect.has(record, 'pendingStatus')) {
        record.pendingStatus = false;
      }
      return h(Switch, {
        checked: record.flag === '1',
        loading: record.pendingStatus,
        onChange(checked: CheckedType) {
          record.pendingStatus = true;
          const newStatus = checked ? '1' : '0';
          const { createMessage } = useMessage();
          if (newStatus === '1') {
            record.flag = '1';
          } else if (newStatus === '0') {
            record.flag = '0';
          }
          changeDataFlagApi(record)
            .then(() => {
              record.flag = newStatus;
              const text = record.flag === '0' ? '停用' : '启用';
              createMessage.success(text + `成功`);
            })
            .catch(() => {
              createMessage.error('操作失败');
            })
            .finally(() => {
              record.pendingStatus = false;
            });
        },
      });
    },
  },
  {
    title: '备注',
    dataIndex: 'remarks',
    width: 150,
  },
  {
    title: '创建时间',
    dataIndex: 'createDate',
    width: 180,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'dictType',
    label: '字典类型',
    component: 'Input',
    colProps: { span: 6 },
    componentProps: {
      disabled: true,
    },
  },
  {
    field: 'dictLabel',
    label: '字典标签',
    component: 'Input',
    componentProps:{
      placeholder: '请输入字典标签',
    },
    colProps: { span: 6 },
  },
  {
    field: 'flag',
    label: '状态',
    component: 'Select',
    componentProps: {
      placeholder: '请选择状态',
      options: [
        { label: '启用', value: '1' },
        { label: '停用', value: '0' },
      ],
    },
    colProps: { span: 6 },
  },
];

export const formSchema: FormSchema[] = [
  {
    field: 'dictType',
    label: '字典类型',
    component: 'Input',
    componentProps: {
      disabled: true,
    },
  },
  {
    field: 'dictLabel',
    label: '参数标签',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入参数标签',
      },
    ],
    componentProps: {
      maxLength: 30,
      showCount: {
        formatter: ({ count }) => `${count} / 30`,
      },
    },
  },
  {
    field: 'dictValue',
    label: '参数键值',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入参数键值',
      },
    ],
    componentProps: {
      maxLength: 300,
      showCount: {
        formatter: ({ count }) => `${count} / 300`,
      },
    },
  },
  {
    field: 'dictSort',
    label: '参数排序',
    component: 'InputNumber',
    rules: [
      {
        required: true,
        message: '请输入参数排序',
      },
    ],
    componentProps: {
      min: 0, // 最小值
      step: 1, // 控制每次增加或减少的数值
    },
  },
  {
    field: 'remarks',
    label: '备注',
    component: 'InputTextArea',
    componentProps: {
      maxLength: 200,
      showCount: {
        formatter: ({ count }) => `${count} / 200`,
      },
    },
  },
];
