import { BasicColumn, FormSchema } from '@/components/Table';
import { h, defineComponent } from 'vue';
import {Select, Switch} from 'ant-design-vue';
import { useMessage } from '@/hooks/web/useMessage';
import {
  changeDataFlagApi,
  changeFlagApi,
  DictDetailApi,
  getDictDataByType
} from '@/api/system/dict/dict';
import { log } from 'vxe-pc-ui';
import { useRouter } from 'vue-router';
import { rowProps } from 'ant-design-vue/es/grid/Row';
import { getDictListByPage,getDictDataByType } from "@/api/system/dict/dict";

type CheckedType = boolean | string | number;



export const columns: BasicColumn[] = [
  {
    title: '序号',
    dataIndex: 'businessId',
    width: 50,
  },
  {
    title: '字典名称',
    dataIndex: 'dictName',
    width: 200,
  },
  {
    title: '字典类型',
    dataIndex: 'dictType',
    width: 180,
    customRender: ({ record }) => {
      const router = useRouter(); // 获取路由实例
      return h(
        'a', // 使用 <a> 标签实现点击跳转
        {
          style: { color: '#1890ff', cursor: 'pointer' }, // 设置样式
          onClick: () => {
            router.push({
              path: '/dict/type/data',
              query: {
                dictType:record.dictType
              },
            });
          },
        },
        record.dictType,
      );
    },
  },
  {
    title: '状态',
    dataIndex: 'flag',
    width: 180,
    customRender: ({ record }) => {
      if (!Reflect.has(record, 'pendingStatus')) {
        record.pendingStatus = false;
      }
      return h(Switch, {
        checked: record.flag === '1',
        loading: record.pendingStatus,
        onChange(checked: CheckedType) {
          record.pendingStatus = true;
          const newStatus = checked ? '1' : '0';
          const { createMessage } = useMessage();
          record.flag = newStatus;
          changeFlagApi(record)
            .then(() => {
              record.flag = newStatus;
              const text = record.flag === '0' ? '停用' : '启用';
              createMessage.success(text + `成功`);
            })
            .catch(() => {
              createMessage.error('操作失败');
            })
            .finally(() => {
              record.pendingStatus = false;
            });
        },
      });
    },
  },
  {
    title: '备注',
    dataIndex: 'remarks',
    width: 180,
  },
  {
    title: '创建时间',
    dataIndex: 'createDate',
    width: 180,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'dictName',
    label: '字典名称',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'dictType',
    label: '字典类型',
    component: 'Input',
    colProps: { span: 7 },
  },
  {
    field: 'flag',
    label: '状态',
    component: 'Select',
    componentProps: {
      options: [
        { label: '启用', value: '1' },
        { label: '停用', value: '0' },
      ],
    },
    colProps: { span: 7 },
  },
  {
    field: 'date',
    label: '创建时间',
    component: 'RangePicker',
    componentProps: {
      format: 'YYYY-MM-DD', // 显示的日期格式
      valueFormat: 'YYYY-MM-DD', // 提交的日期格式
      placeholder: ['开始日期', '结束日期'], // 占位符
      style: { width: '100%' }, // 控制宽度
    },
    colProps: { span: 7 },
  },
];

export const formSchema: FormSchema[] = [
  {
    field: 'dictName',
    label: '字典名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入字典名称',
      },
    ],
    componentProps: {
      placeholder: '请输入字典名称',
    },
  },
  {
    field: 'dictType',
    label: '字典类型',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入字典类型',
      },
    ],
    componentProps: {
      placeholder: '请输入字典类型',
    },
  },
  {
    field: 'parentId',
    label: '父字典名称',
    component: 'Select',
    componentProps: {
       options: [],
       onChange: (value: any, option: any, form: any) => {},
    },
  },
  {
    field: 'dataId',
    label: '父字典数据',
    component: 'Select',
    componentProps: {
      options:[
        {
          dictLabel:'',
          dictValue:''
        }
      ],
    },
    ifShow: false,
  },
  {
    field: 'remarks',
    label: '备注',
    component: 'InputTextArea',
  },
];
