import { BasicColumn, FormSchema } from '@/components/Table';
import { h } from 'vue';
import { Switch } from 'ant-design-vue';
import { setRoleStatus } from '@/api/system/role/role';
import { useMessage } from '@/hooks/web/useMessage';

type CheckedType = boolean | string | number;
export const columns: BasicColumn[] = [
  {
    title: '角色名称',
    dataIndex: 'roleName',
    width: 200,
  },
  {
    title: '权限字符',
    dataIndex: 'roleKey',
    width: 150,
  },
  {
    title: '排序',
    dataIndex: 'roleSort',
    width: 150,
  },
  {
    title: '状态',
    dataIndex: 'flag',
    width: 150,
    customRender: ({ record }) => {
      if (!Reflect.has(record, 'pendingStatus')) {
        record.pendingStatus = false;
      }
      return h(Switch, {
        checked: record.flag === '1',
        // checkedChildren: '停用',
        // unCheckedChildren: '启用',
        loading: record.pendingStatus,
        onChange(checked: CheckedType) {
          record.pendingStatus = true;
          const newStatus = checked ? '1' : '0';
          const { createMessage } = useMessage();
          const params = {
            businessId: record.businessId,
            flag: newStatus,
          }
          setRoleStatus(params)
            .then(() => {
              record.flag = newStatus;
              const text = record.flag === '1' ? '启用' : '停用'
              createMessage.success( text + `成功`);
            })
            .catch(() => {
              // createMessage.error('操作失败');
            })
            .finally(() => {
              record.pendingStatus = false;
            });
        },
      });
    },
  },
  {
    title: '创建时间',
    dataIndex: 'createDate',
    width: 150,
  },
  {
    title: '备注',
    dataIndex: 'remarks',
    width: 150,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'roleName',
    label: '角色名称',
    component: 'Input',
    colProps: { span: 6 },
  },
  {
    field: 'roleKey',
    label: '权限字符',
    component: 'Input',
    colProps: { span: 6 },
  },
  {
    field: 'flag',
    label: '角色状态',
    component: 'Select',
    componentProps: {
      options: [
        { label: '启用', value: '1' },
        { label: '停用', value: '0' },
      ],
    },
    colProps: { span: 6 },
  },
];

export const formSchema: FormSchema[] = [
  {
    field: 'roleName',
    label: '角色名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入角色名称',
      },
    ],
  },
  {
    field: 'roleKey',
    label: '权限字符',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入权限字符',
      },
    ],
  },
  {
    field: 'roleSort',
    label: '角色排序',
    component: 'InputNumber',
    rules: [
      {
        required: true,
        message: '请输入角色排序',
        pattern: /^\d+$/,//需要将返回的数字变成字符串再校验
      },
    ],
    componentProps: {
      min: 0, // 最小值
      max: 9999, // 最大值（根据需要调整）
      step: 1, // 每次增减的步长
      placeholder: '请输入角色排序', // 占位符
      style: { width: '100%' }, // 样式（可选）
    },
  },
  {
    field: 'flag',
    label: '状态',
    component: 'RadioButtonGroup',
    defaultValue: '0',
    componentProps: {
      options: [
        { label: '启用', value: '1' },
        { label: '停用', value: '0' },
      ],
    },
  },
  {
    label: '备注',
    field: 'remarks',
    component: 'InputTextArea',
  },
  {
    label: ' ',
    field: 'menuIds',
    slot: 'menu',
    rules: [
      {
        required: true,
        message: '请选择菜单权限',
      },
    ],
  },
];
